==> edusoho-7.2.9.tar.gz: edusoho/web/bundles/topxiaweb/js/controller/settings/profile.js <==
    define(function(require, exports, module) {

    var Validator = require('bootstrap.validator');
    require("jquery.bootstrap-datetimepicker");
    require('common/validator-rules').inject(Validator);
    require('es-ckeditor');

    exports.run = function() {

        var editor = CKEDITOR.replace('profile_about', {
            toolbar: 'Simple',
            filebrowserImageUploadUrl: $('#profile_about').data('imageUploadUrl')
        });

        // $('.text').each(function() {
        //     var id = $(this).attr('id');
        //     CKEDITOR.replace(id, {
        //         toolbar: 'Simple',
        //         filebrowserImageUploadUrl: $(this).data('imageUploadUrl'),
        //         height: 100
        //     });
        // });

        $(".date").datetimepicker({
            autoclose: true,
            format: 'yyyy-mm-dd',
            minView: 'month'
        });

        var validator = new Validator({
            element: '#user-profile-form',
            failSilently: true,
            onFormValidated: function(error){
                if (error) {
                    return false;
                }
                $('#profile-save-btn').button('submiting').addClass('disabled');
            }
        });

        validator.addItem({
            element: '[name="profile[truename]"]',
            rule: 'minlength{min:2} maxlength{max:36}'
        });

        validator.addItem({
            element: '[name="profile[title]"]',
            rule: 'chinese_limit{max:24}',
            display:Translator.trans('头衔')
        });

        validator.addItem({
            element: '[name="profile[qq]"]',
            rule: 'qq'
        });

        validator.addItem({
            element: '[name="profile[weibo]"]',
            rule: 'url',
            errormessageUrl: Translator.trans(Translator.trans('微博地址不正确，须以http://开头。'))
        });

        validator.addItem({
            element: '[name="profile[blog]"]',
            rule: 'url',
            errormessageUrl: Translator.trans('博客地址不正确，须以http://开头。')
        });

        validator.addItem({
            element: '[name="profile[site]"]',
            rule: 'url',
            errormessageUrl: Translator.trans('个人主页地址不正确，须以http://开头。')
        });

        validator.addItem({
            element: '[name="profile[mobile]"]',
            rule: 'mobile'
        });

        validator.addItem({
            element: '[name="profile[idcard]"]',
            rule: 'idcard'
        });


        for(var i=1;i<=5;i++){
             validator.addItem({
             element: '[name="profile[intField'+i+']"]',
             rule: 'int'
             });

             validator.addItem({
            element: '[name="profile[floatField'+i+']"]',
            rule: 'float'
            });

             validator.addItem({
            element: '[name="profile[dateField'+i+']"]',
            rule: 'date'
             });
        }

        validator.on('formValidate', function(elemetn, event) {
            editor.updateElement();
        });

        if ($('.form-iam-group').length>=1) {

            var iam = $('.form-iam-group').find('input[type=radio]:checked').val();

            $('.form-forIam-group').hide();

            $('.form-'+ iam +'-group').show();

            $('.form-iam-group').on('change', 'input[type=radio]', function() {
                iam = $(this).val();
                $('.form-forIam-group').hide();
                $('.form-'+ iam +'-group').show();
            });
        }

    };

});

==> edusoho-7.5.12.tar.gz: edusoho/web/bundles/topxiaweb/js/controller/settings/profile.js <==
    define(function(require, exports, module) {

    var Validator = require('bootstrap.validator');
    require("jquery.bootstrap-datetimepicker");
    require('common/validator-rules').inject(Validator);
    require('es-ckeditor');

    exports.run = function() {

        var editor = CKEDITOR.replace('profile_about', {
            toolbar: 'Simple',
            filebrowserImageUploadUrl: $('#profile_about').data('imageUploadUrl')
        });

        // $('.text').each(function() {
        //     var id = $(this).attr('id');
        //     CKEDITOR.replace(id, {
        //         toolbar: 'Simple',
        //         filebrowserImageUploadUrl: $(this).data('imageUploadUrl'),
        //         height: 100
        //     });
        // });

        $(".date").datetimepicker({
            autoclose: true,
            format: 'yyyy-mm-dd',
            minView: 'month'
        });

        var validator = new Validator({
            element: '#user-profile-form',
            failSilently: true,
            onFormValidated: function(error){
                if (error) {
                    return false;
                }
                $('#profile-save-btn').button('submiting').addClass('disabled');
            }
        });

        validator.addItem({
            element: '[name="profile[truename]"]',
            rule: 'chinese_alphanumeric byte_minlength{min:4} byte_maxlength{max:36}'
        });

        validator.addItem({
            element: '[name="profile[title]"]',
            rule: 'chinese_limit{max:24}',
            display:Translator.trans('头衔')
        });

        validator.addItem({
            element: '[name="profile[qq]"]',
            rule: 'qq'
        });

        validator.addItem({
            element: '[name="profile[weibo]"]',
            rule: 'url',
            errormessageUrl: Translator.trans(Translator.trans('微博地址不正确，须以http://或者https://开头。'))
        });

        validator.addItem({
            element: '[name="profile[blog]"]',
            rule: 'url',
            errormessageUrl: Translator.trans('博客地址不正确，须以http://或者https://开头。')
        });

        validator.addItem({
            element: '[name="profile[site]"]',
            rule: 'url',
            errormessageUrl: Translator.trans('个人空间地址不正确，须以http://或者https://开头。')
        });

        validator.addItem({
            element: '[name="profile[mobile]"]',
            rule: 'phone'
        });

        validator.addItem({
            element: '[name="profile[idcard]"]',
            rule: 'idcard'
        });


        for(var i=1;i<=5;i++){
             validator.addItem({
             element: '[name="profile[intField'+i+']"]',
             rule: 'int'
             });

             validator.addItem({
            element: '[name="profile[floatField'+i+']"]',
            rule: 'float'
            });

             validator.addItem({
            element: '[name="profile[dateField'+i+']"]',
            rule: 'date'
             });
        }

        validator.on('formValidate', function(elemetn, event) {
            editor.updateElement();
        });

        if ($('.form-iam-group').length>=1) {

            var iam = $('.form-iam-group').find('input[type=radio]:checked').val();

            $('.form-forIam-group').hide();

            $('.form-'+ iam +'-group').show();

            $('.form-iam-group').on('change', 'input[type=radio]', function() {
                iam = $(this).val();
                $('.form-forIam-group').hide();
                $('.form-'+ iam +'-group').show();
            });
        }

    };

});
